'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function ({ types: t }) {
  return {
    visitor: {
      CallExpression(path, state) {
        const callee = path.get('callee');
        if (!callee.isIdentifier() && !isImportLocalName(callee.node.name, state)) {
          return;
        }

        const messagesObj = path.get('arguments')[0];

        if (!(messagesObj && messagesObj.isObjectExpression())) {
          return;
        }

        const prefix = getPrefix(state.file.opts.filename, state.opts.removePrefix || '');

        const properties = messagesObj.get('properties');

        for (const prop of properties) {
          const v = prop.get('value');

          if (!isLiteral(v)) {
            continue;
          }

          const id = getId(prop.get('key'), prefix);

          v.replaceWith(t.objectExpression([t.objectProperty(t.stringLiteral('id'), t.stringLiteral(id)), t.objectProperty(t.stringLiteral('defaultMessage'), v.node)]));
        }
      }
    }
  };
};

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _babelTypes = require('babel-types');

var t = _interopRequireWildcard(_babelTypes);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const PKG_NAME = 'react-intl';
const FUNC_NAME = 'defineMessages';

const isImportLocalName = (name, { file }) => {
  const imports = file.metadata.modules.imports;
  const intlImports = imports.find(x => x.source === PKG_NAME);
  if (intlImports) {
    const specifier = intlImports.specifiers.find(x => x.imported === FUNC_NAME);
    if (specifier) {
      return specifier.local === name;
    }
  }

  return false;
};

const getPrefix = (filename, removePrefix) => {
  const relativePath = _path2.default.dirname(_path2.default.join(_path2.default.relative(process.cwd(), filename)));
  const prefix = relativePath.replace(new RegExp(`^${removePrefix}`), '');
  return prefix;
};

const getId = (path, prefix) => {
  if (!(path.isIdentifier() && path.node.name)) {
    return;
  }
  return _path2.default.join(prefix, path.node.name);
};

const isLiteral = node => t.isStringLiteral(node) || t.isTemplateLiteral(node);